---
title: <span class="badge object-type-scalar"></span> SiShort
---
# <span class="badge object-type-scalar"></span> SiShort

SI short

## Definition

```python
# SI short
SiShort: typing.Literal["sishort"] = "sishort"
```
